pub enum CollectionItemType {
BoardGame,
BoardGameExpansion,
BoardGameAccessory,
}Expand description
The type of an item that can be returned from the collections endpoint.
Either a board game, a board game expansion, or board game accessory, a subset of
ItemType.
Variants
BoardGame
A board game. In many cases the underlying API will also include board game expansions under this type, unless explicitly excluded.
BoardGameExpansion
A board game expansion.
BoardGameAccessory
An accessory for a board game. This can include things such as playmats and miniatures.