pub enum ItemDomain {
Item,
Family,
}Expand description
A domain of item that can either be an item (game, expansion, accessory), or a game family.
Variants
Item
The item domain is used to refer to things like games, expansions, accessories.
Family
The family domain specifically refers to game families.