Struct Plays Copy item path Source pub struct Plays {
pub username: String ,
pub user_id: u64 ,
pub total: u64 ,
pub page: u64 ,
pub plays: Vec <Play >,
}Expand description A play is a recorded instance of someone playing a game. This struct includes one page of a list
of plays, along with the total number in the list.
The username of the user that these plays were requested for. Not included if the plays for
a particular game was requested.
The ID of the user that these plays were requested for. Not included if the plays for a
particular game was requested.
The total number of plays for the query, only up to 100 being returned depending on the
requested page.
The page of plays that is returned in the plays field of this object. Page size is 100.
The list of plays, each item in the list being a recorded instance of someone playing a
game or other item. Includes various information about the session including who played and
how long it lasted.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Deserialize this value from the given Serde deserializer.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.