pub struct PlaysQueryParams { /* private fields */ }Expand description
All optional query parameters for making a request to the plays endpoint.
Implementations
Sourceimpl PlaysQueryParams
impl PlaysQueryParams
Sourcepub fn min_date(self, min_date: NaiveDate) -> Self
pub fn min_date(self, min_date: NaiveDate) -> Self
Sets the min_date parameter. Will only return plays from after this date.
Sourcepub fn max_date(self, max_date: NaiveDate) -> Self
pub fn max_date(self, max_date: NaiveDate) -> Self
Sets the max_date parameter. Will only return plays from up to this date.
Sourcepub fn sub_type(self, sub_type: ItemSubType) -> Self
pub fn sub_type(self, sub_type: ItemSubType) -> Self
Sets the sub_type parameter. Will only return items of the specified type.