ThreadQueryParams

Struct ThreadQueryParams 

pub struct ThreadQueryParams { /* private fields */ }
All optional query parameters for making a request to the thread endpoint.

Implementations

Source

impl ThreadQueryParams

pub fn new() -> Self

Construct a default ThreadQueryParams with no parameters set.

pub fn min_post_id(self, min_post_id: u64) -> Self

Sets the min_post_id query parameter. When set, only include posts with an ID equal to or greater than the requested ID will be returned with the thread.

pub fn min_post_date(self, min_post_date: NaiveDate) -> Self

Sets the min_post_date query parameter. When set, only include posts with a post date equal to or after the the requested ID will be returned with the thread.

pub fn min_post_date_time(self, min_post_date_time: NaiveDateTime) -> Self

Sets the min_post_date query parameter. When set, only include posts with a post date equal to or after the the requested ID will be returned with the thread.

pub fn post_count(self, post_count: u64) -> Self

Sets the post_count query parameter. If set then the number of returned posts will be limited to the requested amount. Max 1000. If unset up to the max of 1000 will be returned.