UserQueryParams

Struct UserQueryParams 

pub struct UserQueryParams { /* private fields */ }
All optional query parameters for making a request to the user endpoint.

Implementations

Source

impl UserQueryParams

pub fn new() -> Self

Construct a default UserQueryParams with no parameters set.

pub fn include_buddies(self, include_buddies: bool) -> Self

Sets the include_buddies query parameter. If set to true then the list of buddies will be returned on the user object.

pub fn include_guilds(self, include_guilds: bool) -> Self

Sets the include_guilds query parameter. If set to true then the list of guilds the user belongs to will be included in the user object.

pub fn include_top_list(self, include_top_list: bool) -> Self

Sets the include_top_list query parameter. If set to true the user’s list of top games will be included in the result.

pub fn include_hot_list(self, include_hot_list: bool) -> Self

Sets the include_hot_list query parameter. If set to true the user’s list of hot games will be included in the result.

pub fn page(self, page: u64) -> Self

Sets the page query parameter. If set then the requested page of buddies and guilds will be returned. If unset the first page will be returned.