pub enum ListItemType {
Thing,
Person,
Company,
Family,
Property,
Event,
}Expand description
A type of item in a user’s top 10, or hot 10 list on their profile. Note that when choosing items on the website
Variants
Thing
A board game, board game expansion, or board game accessory.
Person
A person who is a board game designer, publisher, or artist.
Company
A company designers, or publishes, games.
Family
A certain family of games, can be a certain category, a certain component, or theme. Can also be an accessory family.
Property
A mechanic or category for a game. Mechanics include dice rolling, worker placement, and cooperative game. Categories include word game, and party game.
Event
A board game event or convention.