pub struct ThreadQueryParams { /* private fields */ }Expand description
All optional query parameters for making a request to the thread endpoint.
Implementations
Sourceimpl ThreadQueryParams
impl ThreadQueryParams
Sourcepub fn min_post_id(self, min_post_id: u64) -> Self
pub fn min_post_id(self, min_post_id: u64) -> Self
Sets the min_post_id query parameter. When set, only include posts with an ID equal to or
greater than the requested ID will be returned with the thread.
Sourcepub fn min_post_date(self, min_post_date: NaiveDate) -> Self
pub fn min_post_date(self, min_post_date: NaiveDate) -> Self
Sets the min_post_date query parameter. When set, only include posts with a post date
equal to or after the the requested ID will be returned with the thread.
Sourcepub fn min_post_date_time(self, min_post_date_time: NaiveDateTime) -> Self
pub fn min_post_date_time(self, min_post_date_time: NaiveDateTime) -> Self
Sets the min_post_date query parameter. When set, only include posts with a post date
equal to or after the the requested ID will be returned with the thread.
Sourcepub fn post_count(self, post_count: u64) -> Self
pub fn post_count(self, post_count: u64) -> Self
Sets the post_count query parameter. If set then the number of returned posts will be
limited to the requested amount. Max 1000. If unset up to the max of 1000 will be returned.